#
# spec file for package bsdtar (Version 2.5.5)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           bsdtar
Version:        2.5.5
Release:        18.1
%define pkg_name libarchive
#
License:        BSD 3-clause (or similar)
Group:          Development/Libraries/C and C++
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  libacl-devel zlib-devel
%if 0%{?suse_version} > 1020
BuildRequires:  libbz2-devel
%else
BuildRequires:  bzip2
%endif
%if 0%{?suse_version} >= 1100
BuildRequires:  libext2fs-devel
%else
BuildRequires:  e2fsprogs-devel
%endif
#
Url:            http://people.freebsd.org/~kientzle/libarchive/
#               http://people.freebsd.org/~kientzle/libarchive/src/libarchive-%{version}.tar.gz
Source:         libarchive-%{version}.tar.bz2
Patch:          libarchive-2.5.5_fix_testsuite.patch
Patch1:         libarchive-2.5.5_handle_ENOSYS_from_lutimes.patch
#
Summary:        Bsdtar is a programme that can create and read several different streaming archive formats

%description
Libarchive is a programming library that can create and read several
different streaming archive formats, including most popular tar
variants and several cpio formats. It can also write shar archives and
read ISO9660 CDROM images. The bsdtar program is an implementation of
tar(1) that is built on top of libarchive. It started as a test
harness, but has grown and is now the standard system tar for FreeBSD 5
and 6.

This package contains the bsdtar cmdline utility.



Authors:
--------
    Tim Kientzle <kientzle@freebsd.org>

%package -n libarchive2
License:        BSD 3-clause (or similar)
Group:          Development/Libraries/C and C++
#
Summary:        Programming Library To Create And Read Several Different Streaming Archive Formats

%description -n libarchive2
Libarchive is a programming library that can create and read several
different streaming archive formats, including most popular tar
variants and several cpio formats. It can also write shar archives and
read ISO9660 CDROM images. The bsdtar program is an implementation of
tar(1) that is built on top of libarchive. It started as a test
harness, but has grown and is now the standard system tar for FreeBSD 5
and 6.

The libarchive library offers a number of features that make it both
very flexible and very powerful.

- Automatic format detection: libarchive can automatically determine
   both the compression and the archive format, regardless of the
   data source. Most tar implementations do not automatically detect
   the compression format, few implementation that can correctly do
   this when reading from stdin or a socket. (The tar program
   included with Gunnar Ritter's heirloom collection also does full
   automatic format detection.)

- Writes POSIX formats: libarchive writes POSIX-standard formats,
   including "ustar," "pax interchange format," and the POSIX "cpio"
   format.

- Supports pax interchange format: Pax interchange format (which,
   despite the name, is really an extended tar format) eliminates
   almost all limitations of historic tar formats and provides a
   standard method for incorporating vendor-specific extensions.
   libarchive exploits this extension mechanism to support ACLs and
   file flags, for example. (Joerg Schilling's star archiver is
   another open-source tar program that supports pax interchange
   format.)

- Reads popular formats: libarchive can read GNU tar, ustar, pax
   interchange format, cpio, and older tar variants. The internal
   architecture is easily extensible. The only requirement for
   support is that it be possible to read the format without seeking
   in the file. (For example, a format that includes a compressed
   size field before the data cannot be correctly written without
   seeking.)

- High-Level API: the libarchive API makes it fairly simple to build
   an archive from a list of filenames or to extract the entries
   from an archive. However, the API also provides extreme
   flexibility with regards to data sources. For example, there are
   generic hooks that allow you to write an archive to a socket or
   read data from an archive entry into a memory buffer.

- Extensible. The internal design uses generic interfaces for
compression, archive format detection and decoding, and archive data
I/O. It should be very easy to add new formats, new compression
methods, or new ways of reading/writing archives.



Authors:
--------
    Tim Kientzle <kientzle@freebsd.org>

%package -n libarchive-devel
License:        BSD 3-clause (or similar)
Requires:       libarchive2 = %{version}
Requires:       zlib-devel libacl-devel
%if 0%{?suse_version} > 1020
Requires:       libbz2-devel
%else
Requires:       bzip2
%endif
Group:          Development/Libraries/C and C++
#
Summary:        Development files for libarchive

%description -n libarchive-devel
Libarchive is a programming library that can create and read several
different streaming archive formats, including most popular tar
variants and several cpio formats. It can also write shar archives and
read ISO9660 CDROM images. The bsdtar program is an implementation of
tar(1) that is built on top of libarchive. It started as a test
harness, but has grown and is now the standard system tar for FreeBSD 5
and 6.

This package contains the development files.



Authors:
--------
    Tim Kientzle <kientzle@freebsd.org>

%prep
%setup -q -n %{pkg_name}-%{version}
%patch
%patch1

%build
#autoreconf -fi
%configure --disable-static --enable-bsdcpio
%{__make} %{?_smp_mflags}

%check
%{__make} check

%install
%makeinstall
rm -fv minitar/*.o
rm -fv %{buildroot}%{_libdir}/*.la

%clean
%{__rm} -rf %{buildroot}

%post   -n libarchive2 -p /sbin/ldconfig

%postun -n libarchive2 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/bsdtar
%{_bindir}/bsdcpio
%{_mandir}/man1/*
%{_mandir}/man5/*

%files -n libarchive2
%defattr(-,root,root)
%{_libdir}/libarchive.so.*
%doc COPYING INSTALL NEWS README examples/

%files -n libarchive-devel
%defattr(-,root,root)
%{_mandir}/man3/*
%{_libdir}/libarchive.so
%{_includedir}/archive*

%changelog
* Wed Jan  6 2010 jengelh@medozas.de
- enable parallel building
* Wed Oct 29 2008 mrueckert@suse.de
- added libarchive-2.5.5_handle_ENOSYS_from_lutimes.patch:
  it can happen that your system at build times supports lutimes
  but later at runtime the needed syscall is missing.
* Mon Sep  8 2008 mrueckert@suse.de
- fix rm calls in %%install
* Sat Sep  6 2008 mrueckert@suse.de
- update to 2.5.5
  This is a major version bump again: it incorporates
  lots of bugfixes and improvements.
  For all the details please see
  /usr/share/doc/packages/libarchive2/NEWS
- drop the .la file
- dropped patch libarchive-2.2.5_rpath.patch:
  no longer needed
- added libarchive-2.5.5_fix_testsuite.patch:
  added missing mode to open() with O_CREAT
* Wed Aug 15 2007 ro@suse.de
- fix dependency of devel package
* Tue Aug  7 2007 mrueckert@suse.de
- restructured package:
  bsdtar is now the main package and libarchive2 and libarchive-devel
  the subpackages. This saves us a rename on soversion bumps.
* Mon Jul 30 2007 mrueckert@suse.de
- update to 2.2.5  (#291358)
  This is a major version bump. For a full list of all changes see
  /usr/share/doc/packages/libarchive/NEWS. Mostly notable this up-
  date includes the fixes for the following security bugs:
  Errors handling corrupt tar files in libarchive
  (CVE-2007-3641, CVE-2007-3644, CVE-2007-3645)
- added libarchive-2.2.5_rpath.patch:
  dont set a rpath on the builddir.
- no longer building the static lib
* Thu Jun  7 2007 ro@suse.de
- added ldconfig to post scripts
- remove minitar objects (leave binary there for now)
* Sun Apr  8 2007 mrueckert@suse.de
- updated to 2.0.28
- removed all patches:
  included upstream
* Sat Mar 24 2007 mrueckert@suse.de
- require libbz2-devel on >= 10.3
* Sat Mar 24 2007 aj@suse.de
- Change requires for libbz2 split.
* Tue Mar  6 2007 mrueckert@suse.de
- updated bsdtar-1.2.53_ext2_include.patch:
  the old fix was not complete and on newer glibc/kernel-headers it
  seems you need to include linux/fs.h explicitly
  new name: bsdtar-1.3.1_linux_fs_includes.patch
- build with -fno-strict-aliasing
* Fri Nov 10 2006 mrueckert@suse.de
- added SA-06-24_libarchive.patch:
  fix DOS in libarchive (CVE-2006-5680)
  http://security.freebsd.org/advisories/FreeBSD-SA-06:24.libarchive.asc
* Fri Sep 22 2006 mrueckert@suse.de
- update to version 1.3.1
* Thu Apr 27 2006 mrueckert@suse.de
- updated to 1.2.53:
  Upstream merged the source tarball.
  Splitted of a bsdtar package
* Mon Feb 27 2006 mrueckert@suse.de
- fixed building of debuginfo package
* Mon Feb 27 2006 mrueckert@suse.de
- libarchive 1.2.38
